.. _spkg_papilo:

papilo: Parallel presolve for integer and linear optimization
=======================================================================

Description
-----------

parallel presolve routines for (mixed integer) linear programming
problems. The routines are implemented using templates which allows
switching to higher precision or rational arithmetic using the boost
multiprecision package.


License
-------

LGPL 3.0


Upstream Contact
----------------

https://github.com/scipopt/papilo/

Type
----

optional


Dependencies
------------

- $(BLAS)
- $(MP_LIBRARY)
- :ref:`spkg_boost_cropped`
- :ref:`spkg_cmake`
- :ref:`spkg_gfortran`
- :ref:`spkg_onetbb`

Version Information
-------------------

package-version.txt::

    2.2.1


Equivalent System Packages
--------------------------

(none known)

